@@ -1,4 +1,4 @@
-package Pcore::ExtJS v0.3.2;
+package Pcore::ExtJS v0.3.3;
 
 use Pcore -dist, -class;
 use Pcore::ExtJS::Raw;
@@ -194,6 +194,17 @@ sub ext_type ( $self, $name ) {
     return $type;
 }
 
+sub api_method ( $self, $method_id ) {
+    my $map = $self->{app}->{api}->{map};
+
+    # add version to relative method id
+    $method_id = "/$self->{namespace}->{api_ver}/$method_id" if substr( $method_id, 0, 1 ) ne q[/];
+
+    my $method = $map->get_method($method_id) // die qq[API method "$method_id" is not exists];
+
+    return "$map->{extjs_namespace}.$method->{extjs_action}.$method->{method_name}";
+}
+
 # SERIALIZER
 sub to_js ( $self ) {
     my $cfg = $self->{cfg};
